From 889a89a0ad7c4bd9b6ddb2f6c56c69691542c9cc Mon Sep 17 00:00:00 2001
From: afn <47723802+afnzmn@users.noreply.github.com>
Date: Mon, 24 Oct 2022 16:55:53 -0400
Subject: [PATCH] feat: better spinner
---
src/lib/components/atoms/Spinner.svelte | 43 +++++++++++++------------
src/routes/+layout.svelte | 4 +--
2 files changed, 25 insertions(+), 22 deletions(-)
diff --git a/src/lib/components/atoms/Spinner.svelte b/src/lib/components/atoms/Spinner.svelte
index 31c5e89..4274a7a 100644
--- a/src/lib/components/atoms/Spinner.svelte
+++ b/src/lib/components/atoms/Spinner.svelte
@@ -1,23 +1,26 @@
-
-

-
+
+
diff --git a/src/routes/+layout.svelte b/src/routes/+layout.svelte
index 4716fb9..18d2623 100644
--- a/src/routes/+layout.svelte
+++ b/src/routes/+layout.svelte
@@ -9,8 +9,8 @@
// Just like the set/clearInterval example found here: https://svelte.dev/docs#run-time-svelte-store-derived
const show_loading_animation = derived(RouterEvents, ($event, set) => {
if ($event.navigating) {
- // Wait 300 ms before showing the animation.
- const timeout = setTimeout(() => set(true), 300);
+ // Wait 250 ms before showing the animation.
+ const timeout = setTimeout(() => set(true), 250);
return () => clearTimeout(timeout);
} else {
set(false)